---
sidebar_position: 9
---

# Roadmap

The project roadmap for Zarf is hosted on a [GitHub Project Board](https://github.com/orgs/defenseunicorns/projects/1) that tracks the issues the Zarf team is working along with future work we are prioritizing.

If you would like to add bug reports or feature requests, please [add an issue](https://github.com/defenseunicorns/zarf/issues) to the GitHub repository under the appropriate template.  If you have a more general question about a feature, feel free to ask the team in the [Zarf Kubernetes Slack Channel](https://kubernetes.slack.com/archives/C03B6BJAUJ3).

We also accept contributions from the community (regardless of where a particular bug or feature is on the roadmap), so feel free to read our [contributing guidelines](./12-contribute-to-zarf/1-contributor-guide.md) and [submit a PR](https://github.com/defenseunicorns/zarf/pulls)!  You can also ask any development related questions in the [Zarf Dev Kubernetes Slack Channel](https://kubernetes.slack.com/archives/C03BP9Z3CMA).

## Feature Stability

Zarf has three levels of feature stability that are defined below but generally follow existing Kubernetes conventions.  These communicate how a feature may change in the future as well as expectations for [*ilities](https://en.wiktionary.org/wiki/ility) like documentation.

### `alpha`

Alpha features act as early previews for things that are being considered for inclusion into Zarf and:

 - they are very likely to have breaking changes (or be removed entirely) in future versions of Zarf
 - they will have limited documentation beyond autogenerated CLI and schema documentation (questions should be directed to the [Zarf team](https://kubernetes.slack.com/archives/C03B6BJAUJ3))
 - they will have limited testing and are only recommended for use cases where the risk of instability is acceptable

### `beta`

Beta features are newer features that are being prepared to eventually become stable features and:

 - they may introduce breaking changes before release, but will include any applicable workarounds
 - they will have documentation beyond autogenerated docs, but it won't be fully complete
 - they will have tests that cover their core features, but not covering every flavor of environment

### `stable`

Stable features are features that the Zarf team has committed to maintaining stability for and:

 - they will have backwards compatibility shims introduced in lieu of breaking changes
 - they will have autogenerated docs, tutorials/tutorial mentions, examples, and core docs
 - they will have tests that cover the feature which will run across all tested environments

:::note

While Zarf is pre-General Availability (see below) the above feature stability guidelines should be considered notionally what our expectations are for different Zarf features.  There may be individual cases where *ilities are not met as we work to shore things up for GA.

:::

## General Availability (GA) Release

Right now, Zarf itself is still in its 'beta' phase. We are working on some final things before we release the official 1.0 General Availability (GA) release. The work still needed for the GA release can be found in our issues with [this filter](https://github.com/defenseunicorns/zarf/issues?q=is%3Aopen+is%3Aissue+label%3Aga).

We are currently targeting Q4 2023 to have Zarf be generally available and will be pushing weekly releases until then to add necessary features and fix bugs as well as improve docs, architecture and test coverage behind the scenes.
